svn commit: r254692 - in stable/9/sys: gdb kern ofed/include/linux sys vm

Andriy Gapon avg at FreeBSD.org
Fri Aug 23 13:20:14 UTC 2013


Author: avg
Date: Fri Aug 23 13:20:11 2013
New Revision: 254692
URL: http://svnweb.freebsd.org/changeset/base/254692

Log:
  MFC r253604: rename scheduler->swapper and SI_SUB_RUN_SCHEDULER->SI_SUB_LAST

Modified:
  stable/9/sys/gdb/gdb_cons.c
  stable/9/sys/kern/init_main.c
  stable/9/sys/kern/kern_ntptime.c
  stable/9/sys/kern/sched_4bsd.c
  stable/9/sys/ofed/include/linux/module.h
  stable/9/sys/sys/kernel.h
  stable/9/sys/sys/sched.h
  stable/9/sys/vm/vm.h
  stable/9/sys/vm/vm_glue.c
Directory Properties:
  stable/9/sys/   (props changed)
  stable/9/sys/sys/   (props changed)

Modified: stable/9/sys/gdb/gdb_cons.c
==============================================================================
--- stable/9/sys/gdb/gdb_cons.c	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/gdb/gdb_cons.c	Fri Aug 23 13:20:11 2013	(r254692)
@@ -136,7 +136,7 @@ oktousecallout(void *data __unused)
 {
 	calloutok = 1;
 }
-SYSINIT(gdbhack, SI_SUB_RUN_SCHEDULER, SI_ORDER_MIDDLE, oktousecallout, NULL);
+SYSINIT(gdbhack, SI_SUB_LAST, SI_ORDER_MIDDLE, oktousecallout, NULL);
 
 static void
 gdb_cnputc(struct consdev *cp, int c)

Modified: stable/9/sys/kern/init_main.c
==============================================================================
--- stable/9/sys/kern/init_main.c	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/kern/init_main.c	Fri Aug 23 13:20:11 2013	(r254692)
@@ -236,9 +236,6 @@ restart:
 	/*
 	 * Traverse the (now) ordered list of system initialization tasks.
 	 * Perform each task, and continue on to the next task.
-	 *
-	 * The last item on the list is expected to be the scheduler,
-	 * which will not return.
 	 */
 	for (sipp = sysinit; sipp < sysinit_end; sipp++) {
 
@@ -296,7 +293,13 @@ restart:
 		}
 	}
 
-	panic("Shouldn't get here!");
+	mtx_assert(&Giant, MA_OWNED | MA_NOTRECURSED);
+	mtx_unlock(&Giant);
+
+	/*
+	 * Now hand over this thread to swapper.
+	 */
+	swapper();
 	/* NOTREACHED*/
 }
 
@@ -339,7 +342,7 @@ static char wit_warn[] =
      "WARNING: WITNESS option enabled, expect reduced performance.\n";
 SYSINIT(witwarn, SI_SUB_COPYRIGHT, SI_ORDER_THIRD + 1,
    print_caddr_t, wit_warn);
-SYSINIT(witwarn2, SI_SUB_RUN_SCHEDULER, SI_ORDER_THIRD + 1,
+SYSINIT(witwarn2, SI_SUB_LAST, SI_ORDER_THIRD + 1,
    print_caddr_t, wit_warn);
 #endif
 
@@ -348,7 +351,7 @@ static char diag_warn[] =
      "WARNING: DIAGNOSTIC option enabled, expect reduced performance.\n";
 SYSINIT(diagwarn, SI_SUB_COPYRIGHT, SI_ORDER_THIRD + 2,
     print_caddr_t, diag_warn);
-SYSINIT(diagwarn2, SI_SUB_RUN_SCHEDULER, SI_ORDER_THIRD + 2,
+SYSINIT(diagwarn2, SI_SUB_LAST, SI_ORDER_THIRD + 2,
     print_caddr_t, diag_warn);
 #endif
 

Modified: stable/9/sys/kern/kern_ntptime.c
==============================================================================
--- stable/9/sys/kern/kern_ntptime.c	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/kern/kern_ntptime.c	Fri Aug 23 13:20:11 2013	(r254692)
@@ -1040,5 +1040,5 @@ start_periodic_resettodr(void *arg __unu
 	    periodic_resettodr, NULL);
 }
 
-SYSINIT(periodic_resettodr, SI_SUB_RUN_SCHEDULER, SI_ORDER_MIDDLE,
+SYSINIT(periodic_resettodr, SI_SUB_LAST, SI_ORDER_MIDDLE,
 	start_periodic_resettodr, NULL);

Modified: stable/9/sys/kern/sched_4bsd.c
==============================================================================
--- stable/9/sys/kern/sched_4bsd.c	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/kern/sched_4bsd.c	Fri Aug 23 13:20:11 2013	(r254692)
@@ -143,7 +143,7 @@ static struct kproc_desc sched_kp = {
         schedcpu_thread,
         NULL
 };
-SYSINIT(schedcpu, SI_SUB_RUN_SCHEDULER, SI_ORDER_FIRST, kproc_start,
+SYSINIT(schedcpu, SI_SUB_LAST, SI_ORDER_FIRST, kproc_start,
     &sched_kp);
 SYSINIT(sched_setup, SI_SUB_RUN_QUEUE, SI_ORDER_FIRST, sched_setup, NULL);
 

Modified: stable/9/sys/ofed/include/linux/module.h
==============================================================================
--- stable/9/sys/ofed/include/linux/module.h	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/ofed/include/linux/module.h	Fri Aug 23 13:20:11 2013	(r254692)
@@ -68,17 +68,17 @@ _module_run(void *arg)
 }
 
 #define	module_init(fn)							\
-	SYSINIT(fn, SI_SUB_RUN_SCHEDULER, SI_ORDER_FIRST, _module_run, (fn))
+	SYSINIT(fn, SI_SUB_LAST, SI_ORDER_FIRST, _module_run, (fn))
 
 /*
  * XXX This is a freebsdism designed to work around not having a module
  * load order resolver built in.
  */
 #define	module_init_order(fn, order)					\
-	SYSINIT(fn, SI_SUB_RUN_SCHEDULER, (order), _module_run, (fn))
+	SYSINIT(fn, SI_SUB_LAST, (order), _module_run, (fn))
 
 #define	module_exit(fn)						\
-	SYSUNINIT(fn, SI_SUB_RUN_SCHEDULER, SI_ORDER_FIRST, _module_run, (fn))
+	SYSUNINIT(fn, SI_SUB_LAST, SI_ORDER_FIRST, _module_run, (fn))
 
 #define	module_get(module)
 #define	module_put(module)

Modified: stable/9/sys/sys/kernel.h
==============================================================================
--- stable/9/sys/sys/sched.h	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/sys/sched.h	Fri Aug 23 13:20:11 2013	(r254692)
@@ -180,7 +180,7 @@ static void name ## _add_proc(void *dumm
 	    #name, CTLTYPE_LONG|CTLFLAG_RD|CTLFLAG_MPSAFE,		\
 	    ptr, 0, sysctl_dpcpu_long, "LU", descr);			\
 }									\
-SYSINIT(name, SI_SUB_RUN_SCHEDULER, SI_ORDER_MIDDLE, name ## _add_proc, NULL);
+SYSINIT(name, SI_SUB_LAST, SI_ORDER_MIDDLE, name ## _add_proc, NULL);
 
 #define	SCHED_STAT_DEFINE(name, descr)					\
     DPCPU_DEFINE(unsigned long, name);					\

Modified: stable/9/sys/vm/vm.h
==============================================================================
--- stable/9/sys/vm/vm.h	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/vm/vm.h	Fri Aug 23 13:20:11 2013	(r254692)
@@ -151,6 +151,7 @@ int swap_reserve_by_cred(vm_ooffset_t in
 void swap_reserve_force(vm_ooffset_t incr);
 void swap_release(vm_ooffset_t decr);
 void swap_release_by_cred(vm_ooffset_t decr, struct ucred *cred);
+void swapper(void);
 
 #endif				/* VM_H */
 

Modified: stable/9/sys/vm/vm_glue.c
==============================================================================
--- stable/9/sys/vm/vm_glue.c	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/vm/vm_glue.c	Fri Aug 23 13:20:11 2013	(r254692)
@@ -95,16 +95,6 @@ __FBSDID("$FreeBSD$");
 #include <vm/vm_pager.h>
 #include <vm/swap_pager.h>
 
-/*
- * System initialization
- *
- * THIS MUST BE THE LAST INITIALIZATION ITEM!!!
- *
- * Note: run scheduling should be divorced from the vm system.
- */
-static void scheduler(void *);
-SYSINIT(scheduler, SI_SUB_RUN_SCHEDULER, SI_ORDER_ANY, scheduler, NULL);
-
 #ifndef NO_SWAPPING
 static int swapout(struct proc *);
 static void swapclear(struct proc *);
@@ -691,10 +681,8 @@ faultin(p)
  *
  * Giant is held on entry.
  */
-/* ARGSUSED*/
-static void
-scheduler(dummy)
-	void *dummy;
+void
+swapper(void)
 {
 	struct proc *p;
 	struct thread *td;
@@ -704,9 +692,6 @@ scheduler(dummy)
 	int ppri;
 	int pri;
 
-	mtx_assert(&Giant, MA_OWNED | MA_NOTRECURSED);
-	mtx_unlock(&Giant);
-
 loop:
 	if (vm_page_count_min()) {
 		VM_WAIT;
@@ -757,7 +742,7 @@ loop:
 	 * Nothing to do, back to sleep.
 	 */
 	if ((p = pp) == NULL) {
-		tsleep(&proc0, PVM, "sched", MAXSLP * hz / 2);
+		tsleep(&proc0, PVM, "swapin", MAXSLP * hz / 2);
 		goto loop;
 	}
 	PROC_LOCK(p);


More information about the svn-src-all mailing list
--- stable/9/sys/sys/kernel.h	Fri Aug 23 13:19:12 2013	(r254691)
+++ stable/9/sys/sys/kernel.h	Fri Aug 23 13:20:11 2013	(r254692)
@@ -79,7 +79,7 @@ extern volatile int ticks;
  * enumeration values are explicit rather than implicit to provide
  * for binary compatibility with inserted elements.
  *
  * The SI_SUB_RUN_SCHEDULER value must have the highest lexical value.
  *
  * The SI_SUB_SWAP values represent a value used by
  * the BSD 4.4Lite but not by FreeBSD; it is maintained in dependent
@@ -165,7 +165,7 @@ enum sysinit_sub_id {
 	SI_SUB_KTHREAD_IDLE	= 0xee00000,	/* idle procs*/
 	SI_SUB_SMP		= 0xf000000,	/* start the APs*/
 	SI_SUB_RACCTD		= 0xf100000,	/* start raccd*/
-	SI_SUB_RUN_SCHEDULER	= 0xfffffff	/* scheduler*/
+	SI_SUB_LAST		= 0xfffffff	/* final initialization */
 };
 
 
@@ -79,7 +79,7 @@ extern volatile int ticks;
  * for binary compatibility with inserted elements.
  *
- * The SI_SUB_RUN_SCHEDULER value must have the highest lexical value.
+ * The SI_SUB_LAST value must have the highest lexical value.
  *
  * The SI_SUB_SWAP values represent a value used by

Modified: stable/9/sys/sys/sched.h
==============================================================================